@@ -3,29 +3,29 @@ test_that("maybe_map2 will fail with non-maybe values", {
     a = anything(),
     b = anything(),
     property = function(a, b) {
-      maybe_map2(a, b, identity) %>% expect_error()
-      maybe_map2(just(a), b, identity) %>% expect_error()
-      maybe_map2(a, just(b), identity) %>% expect_error()
-      maybe_map2(nothing(), b, identity) %>% expect_error()
-      maybe_map2(a, nothing(), identity) %>% expect_error()
+      maybe_map2(a, b, list) %>% expect_error()
+      maybe_map2(just(a), b, list) %>% expect_error()
+      maybe_map2(a, just(b), list) %>% expect_error()
+      maybe_map2(nothing(), b, list) %>% expect_error()
+      maybe_map2(a, nothing(), list) %>% expect_error()
     }
   )
 })
 
 test_that("maybe_map2 will fail with a maybe returning function", {
-  safe_identity_list <- function(a, b) just(list(a, b))
+  safe_list <- function(a, b) just(list(a, b))
 
   for_all(
     a = anything(),
     b = anything(),
     property = function(a, b)
-      maybe_map2(just(a), just(b), safe_identity_list) %>%
+      maybe_map2(just(a), just(b), safe_list) %>%
         expect_error()
   )
 })
 
 test_that("maybe_map2 will return nothing if either maybe is nothing", {
-  maybe_map2(nothing(), nothing(), identity) %>%
+  maybe_map2(nothing(), nothing(), list) %>%
     is_nothing() %>%
     expect_true()
 
@@ -33,11 +33,11 @@ test_that("maybe_map2 will return nothing if either maybe is nothing", {
     a = anything(),
     b = anything(),
     property = function(a, b) {
-      maybe_map2(nothing(), just(b), identity) %>%
+      maybe_map2(nothing(), just(b), list) %>%
         is_nothing() %>%
         expect_true()
 
-      maybe_map2(just(a), nothing(), identity) %>%
+      maybe_map2(just(a), nothing(), list) %>%
         is_nothing() %>%
         expect_true()
     }
@@ -45,13 +45,11 @@ test_that("maybe_map2 will return nothing if either maybe is nothing", {
 })
 
 test_that("maybe_map2 will unwrap maybes and rewrap the result", {
-  identity_list <- function(a, b) list(a, b)
-
   for_all(
     a = anything(),
     b = anything(),
     property = function(a, b)
-      maybe_map2(just(a), just(b), identity_list) %>%
-        expect_identical(just(identity_list(a, b)))
+      maybe_map2(just(a), just(b), list) %>%
+        expect_identical(just(list(a, b)))
   )
 })
